@@ -1,4 +1,4 @@
 __version__ = "0.0.1"
 __author__ = "Abhijith Chandradas"
 
-from .pyfinance import *
+from .player import *
